# Visualization Toolkit (VTK) Tcl package configuration.

package ifneeded vtkinit {8.1} {
  namespace eval ::vtk::init {
    proc load_library_package {libName libPath {libPrefix {lib}}} {
      #first try to load a static package, then try the shared package.
      if {[catch "load {} $libName"]} {
        set libExt [info sharedlibextension]
        set currentDirectory [pwd]
        set libFile [file join $libPath "$libPrefix$libName-8.1$libExt"]
        if {[catch "cd {$libPath}; load {$libFile}" errorMessage]} {
          puts $errorMessage
        }
        cd $currentDirectory
      }
    }
    proc require_package {name {version {8.1}}} {
      if {[catch "package require -exact $name $version" errorMessage]} {
        puts $errorMessage
        return 0
      } else {
        return 1
      }
    }
    set version {8.1}
    set kits {}
    foreach kit { base  CommonCore CommonMath CommonMisc CommonSystem CommonTransforms CommonDataModel CommonColor CommonExecutionModel CommonComputationalGeometry FiltersCore FiltersGeneral ImagingCore ImagingFourier FiltersStatistics FiltersExtraction InfovisCore FiltersGeometry FiltersSources RenderingCore RenderingFreeType RenderingContextIID ChartsCore IOCore IOLegacy IOXMLParser DomainsChemistry RenderingOpenGLII RenderingChemistryOpenGLII IOXML ParallelCore FiltersAMR FiltersFlowPaths FiltersGeneric ImagingSources FiltersHybrid FiltersHyperTree ImagingGeneral FiltersImaging FiltersModeling FiltersParallel ParallelMPI FiltersParallelDIYII FiltersParallelGeometry FiltersParallelImaging FiltersParallelMPI FiltersVerdict FiltersParallelVerdict FiltersPoints FiltersProgrammable FiltersSMP FiltersSelection FiltersTexture FiltersTopology InteractionStyle IOSQL IOImage ImagingHybrid InfovisLayout ImagingColor RenderingAnnotation RenderingVolume InteractionWidgets ViewsCore GeovisCore IOAMR IOEnSight IOExodus RenderingGLtoPSOpenGLII IOExport IOExportOpenGLII IOGeometry IOImport IOInfovis IOLSDyna IOMINC IOMPIImage IONetCDF IOParallel IOMPIParallel IOMovie IOPLY IOParallelNetCDF IOParallelXML IOTecplotTable IOVideo ImagingMath ImagingMorphological ImagingStatistics ImagingStencil InteractionImage RenderingContextOpenGLII RenderingImage RenderingLOD RenderingLabel RenderingQt RenderingTk RenderingVolumeOpenGLII TestingRendering ViewsContextIID ViewsInfovis ViewsGeovis } {
      lappend kits [string tolower "${kit}"]
    }
  }
  package provide vtkinit {8.1}
}

foreach kit {  CommonCore CommonMath CommonMisc CommonSystem CommonTransforms CommonDataModel CommonColor CommonExecutionModel CommonComputationalGeometry FiltersCore FiltersGeneral ImagingCore ImagingFourier FiltersStatistics FiltersExtraction InfovisCore FiltersGeometry FiltersSources RenderingCore RenderingFreeType RenderingContextIID ChartsCore IOCore IOLegacy IOXMLParser DomainsChemistry RenderingOpenGLII RenderingChemistryOpenGLII IOXML ParallelCore FiltersAMR FiltersFlowPaths FiltersGeneric ImagingSources FiltersHybrid FiltersHyperTree ImagingGeneral FiltersImaging FiltersModeling FiltersParallel ParallelMPI FiltersParallelDIYII FiltersParallelGeometry FiltersParallelImaging FiltersParallelMPI FiltersVerdict FiltersParallelVerdict FiltersPoints FiltersProgrammable FiltersSMP FiltersSelection FiltersTexture FiltersTopology InteractionStyle IOSQL IOImage ImagingHybrid InfovisLayout ImagingColor RenderingAnnotation RenderingVolume InteractionWidgets ViewsCore GeovisCore IOAMR IOEnSight IOExodus RenderingGLtoPSOpenGLII IOExport IOExportOpenGLII IOGeometry IOImport IOInfovis IOLSDyna IOMINC IOMPIImage IONetCDF IOParallel IOMPIParallel IOMovie IOPLY IOParallelNetCDF IOParallelXML IOTecplotTable IOVideo ImagingMath ImagingMorphological ImagingStatistics ImagingStencil InteractionImage RenderingContextOpenGLII RenderingImage RenderingLOD RenderingLabel RenderingQt RenderingTk RenderingVolumeOpenGLII TestingRendering ViewsContextIID ViewsInfovis ViewsGeovis } {
  package ifneeded "vtk${kit}TCL" {8.1} "
    package require -exact vtkinit {8.1}
    ::vtk::init::load_library_package {vtk${kit}TCL} {[file dirname [file dirname [file dirname [info script]]]]}
  "
  package ifneeded "vtk[string tolower ${kit}]" {8.1} "
    package require -exact vtkinit {8.1}
    if {\[catch {source \[file join {[file dirname [info script]]} {vtk[string tolower ${kit}]} {vtk[string tolower ${kit}].tcl}\]} errorMessage\]} {
      puts \$errorMessage
    }
  "
}

foreach src {vtk vtkbase vtkinteraction vtktesting} {
  package ifneeded ${src} {8.1} "
    package require -exact vtkinit {8.1}
    if {\[catch {source \[file join {[file dirname [info script]]} {$src} {$src.tcl}\]} errorMessage\]} {
      puts \$errorMessage
    }
  "
}
